//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef _MGAGGREGATEGEOMETRY_H_
#define _MGAGGREGATEGEOMETRY_H_

/// \defgroup MgAggregateGeometry MgAggregateGeometry
/// \ingroup Geometry_Module_classes
/// \{

////////////////////////////////////////////////////////////////
/// \brief
/// MgAggregateGeometry is an abstract base class for all of the
/// geometry types that are composed of a set of aggregated
/// geometry objects.
///
/// \remarks
/// The concrete class derived from
/// MgAggregateGeometry are:
/// <ul>
///   <li>MgMultiCurvePolygon</li>
///   <li>MgMultiCurveString</li>
///   <li>MgMultiGeometry</li>
///   <li>MgMultiLineString</li>
///   <li>MgMultiPoint</li>
///   <li>MgMultiPolygon</li>
/// </ul>
///

class MG_GEOMETRY_API MgAggregateGeometry : public MgGeometry
{
public:
    ////////////////////////////////////////////////////
    /// \brief
    /// Gets the number of geometries in this aggregate.
    ///
    /// \return
    /// The number of geometries.
    ///
    virtual int GetCount() = 0;  /// __get

public:

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Gets the geometry at the specified position
    ///
    virtual MgGeometry* GetGeometryAt(int index) = 0;

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Gets a geometry collection, copy of the collection held by this aggregate geometry
    ///
    MgGeometryCollection* CopyCollection();

    /////////////////////////////////////////////////////////////////
    /// \brief
    /// Returns an iterator over the coordinates included in this
    /// geometric entity.
    ///
    /// \return
    /// The coordinates of this geometric entity
    ///
    virtual MgCoordinateIterator* GetCoordinates() = 0;
};
/// \}

#endif //_MGAGGREGATEGEOMETRY_H_
