//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef _MgCoordinateXYM_H_
#define _MgCoordinateXYM_H_

/// \defgroup MgCoordinateXYM MgCoordinateXYM
/// \ingroup Geometry_Module_classes
/// \{

/////////////////////////////////////////////////////////////////
/// \brief
/// MgCoordinateXYM is a concrete class derived from the abstract
/// class MgCoordinate.
///
/// \remarks
/// It has no public constructor. Instances
/// are created by calling the non-static
/// MgGeometryFactory::CreateCoordinateXY() method.
/// \n
/// The M number signifies a unit of measure. The mapping of the
/// M number to a unit of measure is determined by the user.
///
class MG_GEOMETRY_API MgCoordinateXYM : public MgCoordinate
{
public:

    virtual int GetDimension();  /// __get, __inherited

    virtual double GetX();  /// __get, __inherited

    virtual double GetY();  /// __get, __inherited

    virtual double GetZ();  /// __get, __inherited

    virtual double GetM();  /// __get, __inherited

public:

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Construct a MgCoordinateXYImpl object
    ///
    MgCoordinateXYM(double x, double y, double m);

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Construct an empty MgCoordinateXYM object for deserialization
    ///
    MgCoordinateXYM();

    //////////////////////////////////////////////////////////////////
    /// \brief
    /// Returns a copy of this object
    ///
    MgCoordinate* Copy();


    //////////////////////////////////////////////////////////////////
    /// \brief
    /// Test 2 coordinates for equality
    ///
    virtual bool Equals(MgCoordinate* coord);


    ////////////////////////////////////////
    /// \brief
    /// Sets the X value of this coordinate.
    ///
    /// \return
    /// Sets the X value.
    ///
    ///
    virtual void SetX(double x);  /// __get

    ////////////////////////////////////////
    /// \brief
    /// Sets the Y value of this coordinate.
    ///
    /// \return
    /// Sets the Y value.
    ///
    ///
    virtual void SetY(double y);  /// __get

    ////////////////////////////////////////
    /// \brief
    /// Sets the Z value of this coordinate.
    ///
    /// \return
    /// Sets the Z value.
    ///
    ///
    virtual void SetZ(double z);  /// __get

    ////////////////////////////////////////
    /// \brief
    /// Sets the M value of this coordinate.
    ///
    /// \return
    /// Sets the M value.
    ///
    ///
    virtual void SetM(double m);  /// __get

protected:

    //////////////////////////////////////////////
    /// \brief
    /// Dispose this object.
    ///
    virtual void Dispose();

private:
    double      m_x;
    double      m_y;
    double      m_m;
};
/// \}

#endif // _MgCoordinateXYM_H_
