//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

///////////////////////////////////////////////////////////////////////////
// Construct a MgCoordinateXYZ object
//
MgCoordinateXYZ::MgCoordinateXYZ(double x, double y, double z)
{
    m_x = x;
    m_y = y;
    m_z = z;
}

///////////////////////////////////////////////////////////////////////////
// Construct an empty MgCoordinateXYZ object for deserialization
//
MgCoordinateXYZ::MgCoordinateXYZ()
{
}

///////////////////////////////////////////////////////////////////////////
// Defines the dimensions supported by this coordinate as a bit mask. The
// return can be a combination of the values of MgCoordinateDimension.
// See MgCoordinateDimension for an explaination of the possible return
// values.
//
int MgCoordinateXYZ::GetDimension()
{
    return MgCoordinateDimension::XYZ;
}

///////////////////////////////////////////////////////////////////////////
// Gets the X value of this coordinate.
//
double MgCoordinateXYZ::GetX()
{
    return m_x;
}

///////////////////////////////////////////////////////////////////////////
// Gets the Y value of this coordinate.
//
double MgCoordinateXYZ::GetY()
{
    return m_y;
}

///////////////////////////////////////////////////////////////////////////
// Gets the Z value of this coordinate.
//
double MgCoordinateXYZ::GetZ()
{
    return m_z;
}

///////////////////////////////////////////////////////////////////////////
// Gets the M value of this coordinate.
//
double MgCoordinateXYZ::GetM()
{
    return MgCoordinate::NoM;
}

///////////////////////////////////////////////////////////////////////////
// Sets the X value of this coordinate.
//
void MgCoordinateXYZ::SetX(double x)
{
    m_x=x;
}

///////////////////////////////////////////////////////////////////////////
// Sets the Y value of this coordinate.
//
void MgCoordinateXYZ::SetY(double y)
{
    m_y=y;
}

///////////////////////////////////////////////////////////////////////////
// Sets the Z value of this coordinate.
//
void MgCoordinateXYZ::SetZ(double z)
{
    m_z=z;
}

///////////////////////////////////////////////////////////////////////////
// Sets the M value of this coordinate.
//
void MgCoordinateXYZ::SetM(double m)
{
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgCoordinateXYZ::Dispose()
{
    delete this;
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this object
//
MgCoordinate* MgCoordinateXYZ::Copy()
{
    return new MgCoordinateXYZ(m_x, m_y, m_z);
}

//////////////////////////////////////////////////////////////////
// Test 2 coordinates for equality
// Note, both coordinates must be XYZ
//
bool MgCoordinateXYZ::Equals(MgCoordinate* coord)
{
    if(coord == NULL)
    {
        return false;
    }

    MgCoordinateXYZ* c = dynamic_cast<MgCoordinateXYZ*>(coord);
    if (!c)
    {
        return false;
    }

    return m_x == c->m_x &&
           m_y == c->m_y &&
           m_z == c->m_z;
}

