//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef MG_EXCEPTION_H_
#define MG_EXCEPTION_H_

#include "../GeometryCommon.h"

/// \ingroup Exceptions_Module

class MgByteReader;
class MgStringCollection;

///////////////////////////////////////////////////////////////////////////////
/// \brief
/// Base class for exceptions.
///
class MG_GEOMETRY_API MgException : public MgDisposable
{

public:

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Construct the object.
    ///
    /// \param whyMessageId
    /// ID of the message that describes why the exception occurs.
    ///
    MgException(CREFSTRING whyMessageId) throw();
    MgException(const wchar_t* whyMessageId) throw();


    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Retrieve the formatted exception message.  This is the localized and
    /// end user readable string.
    ///
    /// \return
    /// Localized exception message.  See MgSiteConnection for information on specifying
    /// the locale.
    ///
    STRING GetExceptionMessage() throw();

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Retrieve the formatted exception details.  This includes the user readable
    /// string and the stack of method names which generated the error.  This string
    /// provides more information to web application developers than the message.
    /// If a method does not have any parameters it will be omitted from the details.
    ///
    /// \return
    /// Formatted exception details in current locale.  See MgSiteConnection for information on specifying
    /// the locale.
    ///
    STRING GetDetails() throw();


public:


    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Destruct the object.
    ///
    /// \return
    /// Nothing
    ///
    virtual ~MgException() throw();

protected:

    ///////////////////////////////////////////////////////////////////////////
    /// \brief
    /// Dispose this object.
    ///
    /// \return
    /// Nothing
    ///
    virtual void Dispose() throw();

protected:
    /// The localized message.
    STRING m_message;


public:

    virtual void Raise(); 
    protected: 
    MgException() throw();

};

#endif
