//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#pragma once

#include <limits>
#include <float.h>
#include <math.h>
#include <map>
#include <assert.h>
#include <string>
#include <stdlib.h>

#include "GeometryLib.h"

#pragma warning(disable:4251)
typedef std::wstring STRING;
typedef const std::wstring& CREFSTRING;

#include "System/Ptr.h"
#include "System/Disposable.h"
#include "System/DisposableCollection.h"
#include "Exception/Exception.h"

#include "CoordinateDimension.h"
#include "Coordinate.h"
#include "CoordinateXY.h"
#include "CoordinateXYZ.h"
#include "CoordinateXYZM.h"
#include "CoordinateXYM.h"
#include "CoordinateCollection.h"
#include "CoordinateIterator.h"
#include "Transform.h"
#include "Envelope.h"

#include "GeometricEntity.h"
#include "GeometryType.h"
#include "Geometry.h"

#include "GeometryCollection.h"

#include "Point.h"

#include "Ring.h"
#include "LinearRing.h"
#include "LinearRingCollection.h"

#include "LineString.h"
#include "Polygon.h"

#include "LineStringCollection.h"
#include "PolygonCollection.h"
#include "PointCollection.h"

#include "AggregateGeometry.h"
#include "MultiGeometry.h"
#include "MultiLineString.h"
#include "MultiPoint.h"
#include "MultiPolygon.h"

#include "GeometryFactory.h"
#include "GeometryUtil.h"


// Represent NAN for double
#define DoubleNan std::numeric_limits<double>::quiet_NaN()

// Checks whether value is NAN or not
#ifdef _WIN32
#define IsDoubleNan(x)  _isnan(x)
#else
#define IsDoubleNan(x)  isnan(x)
#endif

#define GEOMETRY_SEP    " "
#define POINT_SEPARATOR L", "
