//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

//////////////////////////////////////////////
// Compute the envelope enclosing a line string
//
MgEnvelope* MgGeometryUtil::ComputeLineStringEnvelope(MgCoordinateCollection* coordinates)
{
    Ptr<MgCoordinate> coord = coordinates->GetItem(0);
    double minX = coord->GetX();
    double minY = coord->GetY();
    double maxX = minX;
    double maxY = minY;

    for(int i = 1; i < coordinates->GetCount(); i++)
    {
        coord = coordinates->GetItem(i);
        double x = coord->GetX();
        double y = coord->GetY();

        if(x < minX)
            minX = x;
        else if(x > maxX)
            maxX = x;

        if(y < minY)
            minY = y;
        else if(y > maxY)
            maxY = y;
    }

    Ptr<MgCoordinate> min = new MgCoordinateXY(minX, minY);
    Ptr<MgCoordinate> max = new MgCoordinateXY(maxX, maxY);
    return new MgEnvelope(min, max);
}


//////////////////////////////////////////////
// Compute the envelope enclosing a geometry aggregate
//
MgEnvelope* MgGeometryUtil::ComputeAggregateEnvelope(MgAggregateGeometry* aggrGeometry)
{
    Ptr<MgGeometry> geometry = aggrGeometry->GetGeometryAt(0);
    MgEnvelope* envelope = geometry->Envelope();

    for(int i = 1; i < aggrGeometry->GetCount(); i++)
    {
        geometry = aggrGeometry->GetGeometryAt(i);
        Ptr<MgEnvelope> geomEnvelope = geometry->Envelope();
        envelope->ExpandToInclude(geomEnvelope);
    }
    return envelope;
}

//////////////////////////////////////////////
// Compare a set of coordinates
//
bool MgGeometryUtil::CoordinatesEqual(MgCoordinateCollection* coords1, MgCoordinateCollection* coords2)
{
    int count1 = coords1->GetCount();
    int count2 = coords2->GetCount();

    if(count1 != count2)
        return false;

    Ptr<MgCoordinate> coord1;
    Ptr<MgCoordinate> coord2;

    //compare the collections in the same order
    int i;
    for(i = 0; i < count1; i++)
    {
        coord1 = coords1->GetItem(i);
        coord2 = coords2->GetItem(i);
        if(!coord1->Equals(coord2))
            break;
    }

    if(i == count1)
        return true;

    //compare the collections in the reverse order
    int j;
    for(i = 0, j = count2 - 1; i < count1; i++, j--)
    {
        coord1 = coords1->GetItem(i);
        coord2 = coords2->GetItem(2);
        if(!coord1->Equals(coord2))
            break;
    }

    if(i == count1)
        return true;

    return false;
}
