//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

//////////////////////////////////////////////////////////////////
// Construct a MgLineString object
//
MgLineString::MgLineString(MgCoordinateCollection* coordinates)
{
    if (coordinates->GetCount() < 2)
    {
        throw new MgException(L"MgInvalidGeometryTooFewCoordinates");
    }

    m_coordinates = coordinates->Copy();
}

//////////////////////////////////////////////////////////////////
// Construct an empty MgLineString object for deserialization
//
MgLineString::MgLineString()
{
}

///////////////////////////////////////////////////////////////////////////
// Gets the starting coordinate of the curve.
//
MgCoordinate* MgLineString::GetStartCoordinate()
{
    return m_coordinates->GetItem(0);
}

///////////////////////////////////////////////////////////////////////////
// Gets the ending coordinate of the curve.
//
MgCoordinate* MgLineString::GetEndCoordinate()
{
    return m_coordinates->GetItem(m_coordinates->GetCount() - 1);
}

///////////////////////////////////////////////////////////////////////////
// Returns an iterator that can be used to enumerate each of the line
// strings coordinates.
//
MgCoordinateIterator* MgLineString::GetCoordinates()
{
    return new MgCoordinateIterator(m_coordinates);
}

///////////////////////////////////////////////////////////////////////////
// Gets the type of this geometry.
//
int MgLineString::GetGeometryType()
{
    return MgGeometryType::LineString;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether this entity is empty or not.
//
bool MgLineString::IsEmpty()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether the entities boundary encloses an area.
//
bool MgLineString::IsClosed()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this geometric entity.
//
MgGeometricEntity* MgLineString::Copy()
{
    return new MgLineString(m_coordinates);
}


///////////////////////////////////////////////////////////////////////////
// Returns a transformed copy of this geometric entity.
//
MgGeometricEntity* MgLineString::Transform(MgTransform* transform)
{
    Ptr<MgCoordinateCollection> lineString = new MgCoordinateCollection();

    int count = m_coordinates->GetCount();
    for (int i = 0; i < count; i++)
    {
        Ptr<MgCoordinate> coord = m_coordinates->GetItem(i);
        Ptr<MgCoordinate> newCoord = transform->Transform(coord);
        lineString->Add(newCoord);
    }

    return new MgLineString(lineString);
}


//////////////////////////////////////////////////////////////////
// Calculate the envelope for this geometry
//
MgEnvelope* MgLineString::ComputeEnvelope()
{
    if(m_envelope == NULL)
    {
        m_envelope = MgGeometryUtil::ComputeLineStringEnvelope(m_coordinates);
    }
    return new MgEnvelope(m_envelope);
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgLineString::Dispose()
{
    delete this;
}
