//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

///////////////////////////////////////////////////////////////////////////
///<summary>
/// Construct a MgLineStringCollection objet
///</summary>
MgLineStringCollection::MgLineStringCollection()
{
    m_collection = new MgDisposableCollection();
}

///////////////////////////////////////////////////////////////////////////
///<summary>
/// MgLineStringCollection dtor
///</summary>
MgLineStringCollection::~MgLineStringCollection()
{
    m_collection->Clear();
}

///////////////////////////////////////////////////////////////////////////
// Gets the number of line strings in the collection.
//
int MgLineStringCollection::GetCount() const
{
    return m_collection->GetCount();
}

///////////////////////////////////////////////////////////////////////////
// Gets the line string in the collection at the specified index. Throws
// an invalid argument exception if the index is out of range.
//
MgLineString* MgLineStringCollection::GetItem(int index) const
{
    return (MgLineString*)m_collection->GetItem(index);
}

///////////////////////////////////////////////////////////////////////////
// Sets the line string in the collection at the specified index to the
// specified value. Throws an invalid argument exception if the index is
// out of range.
//
void MgLineStringCollection::SetItem(int index, MgLineString* value)
{
    m_collection->SetItem(index, value);
}

///////////////////////////////////////////////////////////////////////////
// Adds the specified line string to the end of the collection. Returns the
// index of the newly added line string.
//
void MgLineStringCollection::Add(MgLineString* value)
{
    m_collection->Add(value);
}

///////////////////////////////////////////////////////////////////////////
// Inserts the specified line string at the specified index within the
// collection. Items following the insertion point are moved down to
// accommodate the new item. Throws an invalid argument exception if the
// specified index is out of range.
//
void MgLineStringCollection::Insert(int index, MgLineString* value)
{
    m_collection->Insert(index, value);
}

///////////////////////////////////////////////////////////////////////////
// Removes all line strings from the collection.
//
void MgLineStringCollection::Clear()
{
    m_collection->Clear();
}

///////////////////////////////////////////////////////////////////////////
// Removes the specified line string from the collection. Throws an invalid
// argument exception if the item does not exist within the collection.
//
bool MgLineStringCollection::Remove(const MgLineString* value)
{
    bool removed = true;
    try
    {
        m_collection->Remove(value);
    }
    catch (MgException* e)
    {
        e->Release();
        removed = false;
    }
    return removed;
}

///////////////////////////////////////////////////////////////////////////
// Removes the line string at the specified index from the collection.
// Throws an invalid argument exception if the index does not exist within
// the collection.
//
void MgLineStringCollection::RemoveAt(int index)
{
    m_collection->RemoveAt(index);
}

///////////////////////////////////////////////////////////////////////////
// Returns true if the collection contains the specified line string, false
// otherwise.
//
bool MgLineStringCollection::Contains(const MgLineString* value) const
{
    return m_collection->Contains(value);
}

///////////////////////////////////////////////////////////////////////////
// Returns the index of the specified line string in the collection or -1
// if the line string does not exist.
//
int MgLineStringCollection::IndexOf(const MgLineString* value) const
{
    return m_collection->IndexOf(value);
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this collection
//
MgLineStringCollection* MgLineStringCollection::Copy()
{
    MgLineStringCollection* coll = new MgLineStringCollection();
    for(int i = 0; i < GetCount(); i++)
    {
        Ptr<MgLineString> segment = GetItem(i);
        coll->Add(segment);
    }
    return coll;
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgLineStringCollection::Dispose()
{
    delete this;
}

