//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

///////////////////////////////////////////////////////////////////////////
// Construct a MgLinearRing object
//
MgLinearRing::MgLinearRing(MgCoordinateCollection* coordinates)
{
    if (coordinates->GetCount() < 3)
    {
        throw new MgException(L"MgInvalidGeometryTooFewCoordinates");
    }

    m_coordinates = coordinates->Copy();
}

///////////////////////////////////////////////////////////////////////////
// Construct an empty MgLinearRing object for deserialization
//
MgLinearRing::MgLinearRing()
{
}

///////////////////////////////////////////////////////////////////////////
// Returns an iterator that can be used to enumerate each of the linear
// rings coordinates.
//
MgCoordinateIterator* MgLinearRing::GetCoordinates()
{
    return new MgCoordinateIterator(m_coordinates);
}


///////////////////////////////////////////////////////////////////////////
// Tests whether this entity is empty or not.
//
bool MgLinearRing::IsEmpty()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether the entities boundary encloses an area.
//
bool MgLinearRing::IsClosed()
{
    return true;
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this geometric entity.
//
MgGeometricEntity* MgLinearRing::Copy()
{
    return new MgLinearRing(m_coordinates);
}

///////////////////////////////////////////////////////////////////////////
// Returns a transformed copy of this geometric entity.
//
MgGeometricEntity* MgLinearRing::Transform(MgTransform* transform)
{
    Ptr<MgCoordinateCollection> coords = new MgCoordinateCollection();

    int count = m_coordinates->GetCount();

    for (int i = 0; i < count; i++)
    {
        Ptr<MgCoordinate> coord = m_coordinates->GetItem(i);
        Ptr<MgCoordinate> newCoord = transform->Transform(coord);
        coords->Add(newCoord);
    }

    return new MgLinearRing(coords);
}

//////////////////////////////////////////////////////////////////
// Calculate the envelope for this geometry
//
MgEnvelope* MgLinearRing::ComputeEnvelope()
{
    if(m_envelope == NULL)
    {
        m_envelope = MgGeometryUtil::ComputeLineStringEnvelope(m_coordinates);
    }
    return new MgEnvelope(m_envelope);
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgLinearRing::Dispose()
{
    delete this;
}

///////////////////////////////////////////////////////////////////////////
// Returns the coordinates for this ring
// rings coordinates.
//
MgCoordinateCollection* MgLinearRing::GetCoordinateCollection()
{
    return SAFE_ADDREF((MgCoordinateCollection*)m_coordinates);
}
