//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

//////////////////////////////////////////////////////////////////
// Construct a MgMultiPoint object
//
MgMultiPoint::MgMultiPoint(MgPointCollection* points)
{
    m_points = points->Copy();
}

//////////////////////////////////////////////////////////////////
// Construct an empty MgMultiPoint object for deserialization
//
MgMultiPoint::MgMultiPoint()
{
}

///////////////////////////////////////////////////////////////////////////
// Gets the number of geometries in this aggregate.
//
int MgMultiPoint::GetCount()
{
    return m_points->GetCount();
}

///////////////////////////////////////////////////////////////////////////
// Gets the point at the specified index. The indexing starts at
// zero.
//
MgPoint* MgMultiPoint::GetPoint(int index)
{
    return m_points->GetItem(index);
}

///////////////////////////////////////////////////////////////////////////
// Gets the type of this geometry.
//
int MgMultiPoint::GetGeometryType()
{
    return MgGeometryType::MultiPoint;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether this entity is empty or not.
//
bool MgMultiPoint::IsEmpty()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether the entities boundary encloses an area.
//
bool MgMultiPoint::IsClosed()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this geometric entity.
//
MgGeometricEntity* MgMultiPoint::Copy()
{
    Ptr<MgPointCollection> points = m_points->Copy();
    return new MgMultiPoint(points);
}

///////////////////////////////////////////////////////////////////////////
// Returns a transformed copy of this geometric entity.
//
MgGeometricEntity* MgMultiPoint::Transform(MgTransform* transform)
{
    Ptr<MgPointCollection> points = new MgPointCollection();

    int count = m_points->GetCount();
    for (int i = 0; i < count; i++)
    {
        Ptr<MgPoint> point = m_points->GetItem(i);
        Ptr<MgPoint> newPoint = (MgPoint*)point->Transform(transform);
        points->Add(newPoint);
    }

    return new MgMultiPoint(points);
}


//////////////////////////////////////////////////////////////////
// Calculate the envelope for this geometry
//
MgEnvelope* MgMultiPoint::ComputeEnvelope()
{
    if(m_envelope == NULL)
    {
        m_envelope = MgGeometryUtil::ComputeAggregateEnvelope(this);
    }
    return new MgEnvelope(m_envelope);
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgMultiPoint::Dispose()
{
    delete this;
}

///////////////////////////////////////////////////////////////////////////
// Gets the geometry at the specified position
//
MgGeometry* MgMultiPoint::GetGeometryAt(int index)
{
    return GetPoint(index);
}

MgCoordinateIterator* MgMultiPoint::GetCoordinates()
{
    Ptr<MgCoordinateCollection> coords = new MgCoordinateCollection();
    int count = m_points->GetCount();

    for (int i = 0; i < count; i++)
    {
        Ptr<MgPoint> point = m_points->GetItem(i);
        coords->Add(Ptr<MgCoordinate>(point->GetCoordinate()));
    }

    return new MgCoordinateIterator(coords);
}
