//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

//////////////////////////////////////////////////////////////////
// Construct a MgMultiPolygon object
//
MgMultiPolygon::MgMultiPolygon(MgPolygonCollection* polygons)
{
    m_polygons = polygons->Copy();
}

//////////////////////////////////////////////////////////////////
// Construct an empty MgMultiPolygon object for deserialization
//
MgMultiPolygon::MgMultiPolygon()
{
}

///////////////////////////////////////////////////////////////////////////
// Gets the number of geometries in this aggregate.
//
int MgMultiPolygon::GetCount()
{
    return m_polygons->GetCount();
}

///////////////////////////////////////////////////////////////////////////
// Gets the polygon at the specified index. The indexing starts at
// zero.
//
MgPolygon* MgMultiPolygon::GetPolygon(int index)
{
    return m_polygons->GetItem(index);
}

///////////////////////////////////////////////////////////////////////////
// Gets the type of this geometry.
//
int MgMultiPolygon::GetGeometryType()
{
    return MgGeometryType::MultiPolygon;
}


///////////////////////////////////////////////////////////////////////////
// Tests whether this entity is empty or not.
//
bool MgMultiPolygon::IsEmpty()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether the entities boundary encloses an area.
//
bool MgMultiPolygon::IsClosed()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this geometric entity.
//
MgGeometricEntity* MgMultiPolygon::Copy()
{
    Ptr<MgPolygonCollection> polygons = m_polygons->Copy();
    return new MgMultiPolygon(polygons);
}

///////////////////////////////////////////////////////////////////////////
// Returns a transformed copy of this geometric entity.
//
MgGeometricEntity* MgMultiPolygon::Transform(MgTransform* transform)
{
    Ptr<MgPolygonCollection> polygons = new MgPolygonCollection();

    int count = m_polygons->GetCount();
    for (int i = 0; i < count; i++)
    {
        Ptr<MgPolygon> polygon = m_polygons->GetItem(i);
        Ptr<MgPolygon> newPolygon = (MgPolygon*)polygon->Transform(transform);
        polygons->Add(newPolygon);
    }

    return new MgMultiPolygon(polygons);
}

//////////////////////////////////////////////////////////////////
// Calculate the envelope for this geometry
//
MgEnvelope* MgMultiPolygon::ComputeEnvelope()
{
    if(m_envelope == NULL)
    {
        m_envelope = MgGeometryUtil::ComputeAggregateEnvelope(this);
    }
    return new MgEnvelope(m_envelope);
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgMultiPolygon::Dispose()
{
    delete this;
}

///////////////////////////////////////////////////////////////////////////
// Gets the geometry at the specified position
//
MgGeometry* MgMultiPolygon::GetGeometryAt(int index)
{
    return GetPolygon(index);
}


MgCoordinateIterator* MgMultiPolygon::GetCoordinates()
{
    Ptr<MgCoordinateCollection> coords = new MgCoordinateCollection();
    int count = m_polygons->GetCount();

    for (int i = 0; i < count; i++)
    {
        Ptr<MgPolygon> polygon = m_polygons->GetItem(i);
        Ptr<MgCoordinateIterator> polyIterator = polygon->GetCoordinates();

        while (polyIterator->MoveNext())
        {
            coords->Add(Ptr<MgCoordinate>(polyIterator->GetCurrent()));
        }
    }

    return new MgCoordinateIterator(coords);
}
