//
//  Copyright (C) 2004-2011 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "stdafx.h"

//////////////////////////////////////////////////////////////////
// Construct a MgPoint object
//
MgPoint::MgPoint(MgCoordinate* coordinate)
{
    m_coord = SAFE_ADDREF((MgCoordinate*)coordinate);
}

//////////////////////////////////////////////////////////////////
// Construct an empty MgPoint object for deserialization
//
MgPoint::MgPoint()
{
}

///////////////////////////////////////////////////////////////////////////
// Gets the type of this geometry.
//
int MgPoint::GetGeometryType()
{
    return MgGeometryType::Point;
}


///////////////////////////////////////////////////////////////////////////
// Tests whether this entity is empty or not.
//
bool MgPoint::IsEmpty()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Tests whether the entities boundary encloses an area.
//
bool MgPoint::IsClosed()
{
    return false;
}

///////////////////////////////////////////////////////////////////////////
// Gets the coordinate that defines this point.
//
MgCoordinate* MgPoint::GetCoordinate()
{
    return SAFE_ADDREF((MgCoordinate*)m_coord);
}

///////////////////////////////////////////////////////////////////////////
// Returns a copy of this geometric entity.
//
MgGeometricEntity* MgPoint::Copy()
{
    return new MgPoint(m_coord);
}

///////////////////////////////////////////////////////////////////////////
// Returns a transformed copy of this geometric entity.
//
MgGeometricEntity* MgPoint::Transform(MgTransform* transform)
{
    Ptr<MgCoordinate> coord = transform->Transform(m_coord);
    return new MgPoint(coord);
}

//////////////////////////////////////////////////////////////////
// Calculate the envelope for this geometry
//
MgEnvelope* MgPoint::ComputeEnvelope()
{
    return new MgEnvelope(m_coord, m_coord);
}

//////////////////////////////////////////////
// Dispose this object.
//
void MgPoint::Dispose()
{
    delete this;
}

MgCoordinateIterator* MgPoint::GetCoordinates()
{
    Ptr<MgCoordinateCollection> coords = new MgCoordinateCollection();
    Ptr<MgCoordinate> coordCopy = m_coord->Copy();
    coords->Add(coordCopy);

    return new MgCoordinateIterator(coords);
}
